mapByte method
Maps the contents of this array into native types. Only works if childSignature is 'y'.
Implementation
Iterable<int> mapByte() => children.map((value) => (value as DBusByte).value);
Maps the contents of this array into native types. Only works if childSignature is 'y'.
Iterable<int> mapByte() => children.map((value) => (value as DBusByte).value);