mapInt16 method
Maps the contents of this array into native types. Only works if childSignature is 'n'.
Implementation
Iterable<int> mapInt16() =>
children.map((value) => (value as DBusInt16).value);
Maps the contents of this array into native types. Only works if childSignature is 'n'.
Iterable<int> mapInt16() =>
children.map((value) => (value as DBusInt16).value);