mapInt64 method
Maps the contents of this array into native types. Only works if childSignature is 'x'.
Implementation
Iterable<int> mapInt64() =>
children.map((value) => (value as DBusInt64).value);
Maps the contents of this array into native types. Only works if childSignature is 'x'.
Iterable<int> mapInt64() =>
children.map((value) => (value as DBusInt64).value);