mapSignature method
Maps the contents of this array into native types. Only works if childSignature is 'g'.
Implementation
Iterable<DBusSignature> mapSignature() =>
children.map((value) => value as DBusSignature);
Maps the contents of this array into native types. Only works if childSignature is 'g'.
Iterable<DBusSignature> mapSignature() =>
children.map((value) => value as DBusSignature);