mapString method
Maps the contents of this array into native types. Only works if childSignature is 's'.
Implementation
Iterable<String> mapString() =>
children.map((value) => (value as DBusString).value);
Maps the contents of this array into native types. Only works if childSignature is 's'.
Iterable<String> mapString() =>
children.map((value) => (value as DBusString).value);