mapUint16 method
Maps the contents of this array into native types. Only works if childSignature is 'q'.
Implementation
Iterable<int> mapUint16() =>
children.map((value) => (value as DBusUint16).value);
Maps the contents of this array into native types. Only works if childSignature is 'q'.
Iterable<int> mapUint16() =>
children.map((value) => (value as DBusUint16).value);