mapUint32 method
Maps the contents of this array into native types. Only works if childSignature is 'u'.
Implementation
Iterable<int> mapUint32() =>
children.map((value) => (value as DBusUint32).value);
Maps the contents of this array into native types. Only works if childSignature is 'u'.
Iterable<int> mapUint32() =>
children.map((value) => (value as DBusUint32).value);