mapUint64 method
Maps the contents of this array into native types. Only works if childSignature is 't'.
Implementation
Iterable<int> mapUint64() =>
children.map((value) => (value as DBusUint64).value);
Maps the contents of this array into native types. Only works if childSignature is 't'.
Iterable<int> mapUint64() =>
children.map((value) => (value as DBusUint64).value);