mapVariant method
Maps the contents of this array into native types. Only works if childSignature is 'v'.
Implementation
Iterable<DBusValue> mapVariant() =>
children.map((value) => (value as DBusVariant).value);
Maps the contents of this array into native types. Only works if childSignature is 'v'.
Iterable<DBusValue> mapVariant() =>
children.map((value) => (value as DBusVariant).value);