DBusByte class

D-Bus representation of an unsigned 8 bit value.

Inheritance

Constructors

DBusByte(int value)
Creates a new byte with the given value.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature DBusSignature
Gets the signature for this value.
no setteroverride
value int
A integer in the range 0, 255
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative() → dynamic
Converts this value to a native Dart representation.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override