DBusDict class

D-Bus representation of an associative array of D-Bus values.

Inheritance

Constructors

DBusDict(DBusSignature keySignature, DBusSignature valueSignature, [Map<DBusValue, DBusValue> children = const {}])
Creates a new dictionary with keys of the type keySignature and values of the type valueSignature. keySignature and valueSignature must a single type. D-Bus doesn't allow sending and receiving dicts with keys that not basic types, i.e. byte, boolean, int16, uint16, int32, uint32, int64, uint64, double or unix_fd. An exception will be thrown when sending a message containing dicts using other types for keys.
DBusDict.stringVariant(Map<String, DBusValue> children)
Creates a new dictionary of string keys mapping to variant values.
factory
DBusDict.unchecked(DBusSignature keySignature, DBusSignature valueSignature, [Map<DBusValue, DBusValue> children = const {}])
Creates a new dictionary with keys of the type keySignature and values of the type valueSignature.
const

Properties

children Map<DBusValue, DBusValue>
The child values in this dictionary.
final
hashCode int
The hash code for this object.
no setteroverride
keySignature DBusSignature
Signature of the key type in this dictionary.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature DBusSignature
Gets the signature for this value.
no setteroverride
valueSignature DBusSignature
Signature of the value type in this dictionary.
final

Methods

mapStringVariant() Map<String, DBusValue>
Maps the contents of this array into native types. Only works if keySignature is 's' and valueSignature is 'v'.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative() → dynamic
Converts this value to a native Dart representation.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override