DBusString constructor
const
DBusString(
- String value
Creates a new Unicode text string with the given value.
Implementation
const DBusString(this.value);
Creates a new Unicode text string with the given value.
const DBusString(this.value);