DBusUint64 class

D-Bus representation of an unsigned 64 bit integer.

Inheritance

Constructors

DBusUint64(int value)
Creates a new unsigned 64 bit integer with the given value.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature DBusSignature
Gets the signature for this value.
no setteroverride
value int
An integer in the range 0, 18446744073709551615
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative() → dynamic
Converts this value to a native Dart representation.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override