DBusVariant class

D-Bus value that contains any D-Bus type.

Inheritance

Constructors

DBusVariant(DBusValue value)
Creates a new D-Bus variant containing value.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature DBusSignature
Gets the signature for this value.
no setteroverride
value DBusValue
The value contained in this variant.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative() → dynamic
Converts this value to a native Dart representation.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override