DBusArray class
D-Bus representation of an ordered list of D-Bus values of the same type.
Constructors
-
DBusArray(DBusSignature childSignature, [Iterable<
DBusValue> children = const []]) -
Creates a new empty D-Bus array containing
children. -
DBusArray.byte(Iterable<
int> values) -
Creates a new array of unsigned 8 bit values.
factory
-
DBusArray.double(Iterable<
double> values) -
Creates a new array of 64 bit floating point values.
factory
-
DBusArray.int16(Iterable<
int> values) -
Creates a new array of signed 16 bit values.
factory
-
DBusArray.int32(Iterable<
int> values) -
Creates a new array of signed 32 bit values.
factory
-
DBusArray.int64(Iterable<
int> values) -
Creates a new array of signed 64 bit values.
factory
-
DBusArray.objectPath(Iterable<
DBusObjectPath> values) -
Creates a new array of D-Bus object paths.
factory
-
DBusArray.signature(Iterable<
DBusSignature> values) -
Creates a new array of D-Bus signatures.
factory
-
DBusArray.string(Iterable<
String> values) -
Creates a new array of Unicode text strings.
factory
-
DBusArray.uint16(Iterable<
int> values) -
Creates a new array of unsigned 16 bit values.
factory
-
DBusArray.uint32(Iterable<
int> values) -
Creates a new array of unsigned 32 bit values.
factory
-
DBusArray.uint64(Iterable<
int> values) -
Creates a new array of unsigned 64 bit values.
factory
-
DBusArray.unchecked(DBusSignature childSignature, [Iterable<
DBusValue> children = const []]) -
Creates a new empty D-Bus array containing
children. -
DBusArray.variant(Iterable<
DBusValue> values) -
Creates a new array of D-Bus variants.
factory
Properties
-
children
→ List<
DBusValue> -
Ordered list of children in this array.
final
- childSignature → DBusSignature
-
Signature of the type of children in this array.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → DBusSignature
-
Gets the signature for this value.
no setteroverride
Methods
-
mapByte(
) → Iterable< int> - Maps the contents of this array into native types. Only works if childSignature is 'y'.
-
mapDouble(
) → Iterable< double> - Maps the contents of this array into native types. Only works if childSignature is 'd'.
-
mapInt16(
) → Iterable< int> - Maps the contents of this array into native types. Only works if childSignature is 'n'.
-
mapInt32(
) → Iterable< int> - Maps the contents of this array into native types. Only works if childSignature is 'i'.
-
mapInt64(
) → Iterable< int> - Maps the contents of this array into native types. Only works if childSignature is 'x'.
-
mapObjectPath(
) → Iterable< DBusObjectPath> - Maps the contents of this array into native types. Only works if childSignature is 'o'.
-
mapSignature(
) → Iterable< DBusSignature> - Maps the contents of this array into native types. Only works if childSignature is 'g'.
-
mapString(
) → Iterable< String> - Maps the contents of this array into native types. Only works if childSignature is 's'.
-
mapUint16(
) → Iterable< int> - Maps the contents of this array into native types. Only works if childSignature is 'q'.
-
mapUint32(
) → Iterable< int> - Maps the contents of this array into native types. Only works if childSignature is 'u'.
-
mapUint64(
) → Iterable< int> - Maps the contents of this array into native types. Only works if childSignature is 't'.
-
mapVariant(
) → Iterable< DBusValue> - Maps the contents of this array into native types. Only works if childSignature is 'v'.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
) → dynamic -
Converts this value to a native Dart representation.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override