DBusMaybe class
D-Bus value that contains a D-Bus type or null. This type is reserved for future use, and is not currently able to be sent or received using D-Bus.
Constructors
- DBusMaybe(DBusSignature valueSignature, DBusValue? value)
-
Creates a new D-Bus maybe containing
value.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → DBusSignature
-
Gets the signature for this value.
no setteroverride
- value → DBusValue?
-
The value contained in this maybe.
final
- valueSignature → DBusSignature
-
Signature of the value this maybe contains.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
) → dynamic -
Converts this value to a native Dart representation.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override