DBusServer class
A D-Bus server.
Constructors
- DBusServer()
- Creates a new DBus server.
Properties
-
activatableNames
→ List<
String> -
Names of services that can be activated.
Override this property to enable this feature.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid → String
-
Unique ID for this server;
no setter
Methods
-
close(
) → Future< void> - Terminates all active connections. If a server remains unclosed, the Dart process may not terminate.
-
listenAddress(
DBusAddress address) → Future< DBusAddress> -
Listen on the given D-Bus
address. Returns an address for clients to connnect on this connection. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startServiceByName(
String name) → Future< DBusServerStartServiceResult> -
Start a service that uses
name. Override this method to enable this feature. -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited