DBusSignature class
D-Bus value that indicates a set of D-Bus types.
A signature may be empty (''), contain a single type (e.g. 's'), or contain multiple types (e.g. 'asbo').
The following patterns map to classes:
y→ DBusByteb→ DBusBooleann→ DBusInt16q→ DBusUint16i→ DBusInt32u→ DBusUint32x→ DBusInt64t→ DBusUint64d→ DBusDoubles→ DBusStringo→ DBusObjectPathg→ DBusSignaturev→ DBusVariantm→ DBusMaybe- 'h' → DBusUnixFd
(xyz...)→ DBusStruct (x,y,zrepresent the child value signatures).av→ DBusArray (v represents the array value signature).a{kv}→ DBusDict (kandvrepresent the key and value signatures).
Constructors
- DBusSignature(String value)
-
Create a new D-Bus signature with the given
value. - DBusSignature.array(DBusSignature type)
-
Create a new D-Bus signature of an array of the given
type(DBusArray).factory - DBusSignature.dict(DBusSignature key, DBusSignature value)
-
Create a new D-Bus signature of a dictionary of the given
keyandvaluetypes (DBusDict).factory - DBusSignature.maybe(DBusSignature type)
-
Create a new D-Bus signature of a value that contains a D-Bus type or null (DBusMaybe).
factory
-
DBusSignature.struct(Iterable<
DBusSignature> types) -
Create a new D-Bus signature of a struct of the given
types(DBusStruct).factory - DBusSignature.unchecked(String value)
-
Create a new D-Bus signature with the given
value.const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isBasic → bool
-
True if this signature is for a basic type (byte, boolean, int16, uint16, int32, uint32, int64, uint64, double, unix_fd).
no setter
- isSingleCompleteType → bool
-
True if this signature is for a single complete type, i.e. represents a single dbus value.
If False, then use split to get the types this signature contains.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → DBusSignature
-
Gets the signature for this value.
no setteroverride
- value → String
-
A D-Bus signature string.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
split(
) → List< DBusSignature> -
Splits this signature into a list of signatures with single complete types, e.g. 'asbo' ->
'as', 'b', 'o' -
toNative(
) → dynamic -
Converts this value to a native Dart representation.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator +(
DBusSignature other) → DBusSignature -
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- boolean → const DBusSignature
- D-Bus signature of a boolean value (DBusBoolean).
- byte → const DBusSignature
- D-Bus signature of an unsigned 8 bit value (DBusByte).
- double → const DBusSignature
- D-Bus signature of a 64 bit floating point value (DBusDouble).
- empty → const DBusSignature
- Empty "void" signature.
- int16 → const DBusSignature
- D-Bus signature of a signed 16 bit integer (DBusInt16).
- int32 → const DBusSignature
- D-Bus signature of a signed 32 bit integer (DBusInt32).
- int64 → const DBusSignature
- D-Bus signature of a signed 64 bit integer (DBusInt64).
- objectPath → const DBusSignature
- D-Bus signature of an object path (DBusObjectPath).
- string → const DBusSignature
- D-Bus signature of a Unicode text string (DBusString).
- uint16 → const DBusSignature
- D-Bus signature of an unsigned 16 bit integer (DBusUint16).
- uint32 → const DBusSignature
- D-Bus signature of an unsigned 32 bit integer (DBusUint32).
- uint64 → const DBusSignature
- D-Bus signature of an unsigned 64 bit integer (DBusUint64).
- unixFd → const DBusSignature
- D-Bus signature of a Unix file descriptor (DBusUnixFd).
- variant → const DBusSignature
- Create a new D-Bus signature of a variant that contains any D-Bus type (DBusVariant).