DBusStruct class
D-Bus value that contains a fixed set of other values.
Constructors
-
DBusStruct(Iterable<
DBusValue> children) -
Creates a new D-Bus structure containing
childrenvalues.
Properties
-
children
→ List<
DBusValue> -
Child values in this structure.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → DBusSignature
-
Gets the signature for this value.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNative(
) → dynamic -
Converts this value to a native Dart representation.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override